import { CanvasStore, DestroyedService, runOutsideAngular, } from '@angular-three/core';
import { Directive, EventEmitter, Input, NgZone, Output, SkipSelf, } from '@angular/core';
import { takeUntil } from 'rxjs/operators';
import { AudioListener } from 'three';
export class AudioListenerDirective {
    constructor(canvasStore, destroyed, ngZone) {
        this.canvasStore = canvasStore;
        this.destroyed = destroyed;
        this.ngZone = ngZone;
        this.ready = new EventEmitter();
        this.zonelessReady = new EventEmitter();
    }
    ngOnInit() {
        this.ngZone.runOutsideAngular(() => {
            this._listener = new AudioListener();
            if (this.filter) {
                this._listener.filter = this.filter;
            }
            if (this.timeDelta) {
                this._listener.timeDelta = this.timeDelta;
            }
            this.canvasStore.active$
                .pipe(runOutsideAngular(this.ngZone, (active, run) => {
                const { camera } = this.canvasStore.getImperativeState();
                if (active && camera) {
                    camera.add(this.audioListener);
                    run(() => {
                        this.ready.emit(this.audioListener);
                    });
                    this.zonelessReady.emit(this.audioListener);
                }
            }), takeUntil(this.destroyed))
                .subscribe();
        });
    }
    get audioListener() {
        return this._listener;
    }
}
AudioListenerDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-audioListener',
                exportAs: 'ngtAudioListener',
                providers: [DestroyedService],
            },] }
];
AudioListenerDirective.ctorParameters = () => [
    { type: CanvasStore, decorators: [{ type: SkipSelf }] },
    { type: DestroyedService },
    { type: NgZone }
];
AudioListenerDirective.propDecorators = {
    filter: [{ type: Input }],
    timeDelta: [{ type: Input }],
    ready: [{ type: Output }],
    zonelessReady: [{ type: Output }]
};
//# sourceMappingURL=audio-listener.directive.js.map